package dev.ksan;

import java.io.*;
import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;

public class DataStore {

    public static Map<Subject,Subscription> subjectSubscriptions = new ConcurrentHashMap<>();
    private static final String DATA_FILE = "subjects_data.ser";
    static{
        loadSubjectsFromFile();
    }

    public static void notifySubject(Subject subject, SubjectEntry entry){
        subjectSubscriptions.get(subject).notifyUsers(entry);
    }
    public static synchronized void subscribeUserToSubject(User user, Subject subject) {
        if (user != null && subject != null && subjectSubscriptions.containsKey(subject)) {
            subjectSubscriptions.get(subject).subscribe(user);
            user.addSubject(subject);
        }
    }

    public synchronized void unsubscribeUserFromSubject(User user, Subject subject) {
        if (user != null && subject != null && subjectSubscriptions.containsKey(subject)) {
            Subscription subscription = subjectSubscriptions.get(subject);
            if (subscription != null) {
                subscription.unsubscribe(user);
            }
        }
    }
    private static void loadSubjectsFromFile() {
        try (ObjectInputStream in = new ObjectInputStream(new FileInputStream(DATA_FILE))) {
            subjectSubscriptions = (Map<Subject, Subscription>) in.readObject();
        } catch (IOException | ClassNotFoundException e) {
            System.out.println("Error loading subjects data: " + e.getMessage());
        }
    }

    private static void saveSubjectsToFile() {
        try (ObjectOutputStream out = new ObjectOutputStream(new FileOutputStream(DATA_FILE))) {
            out.writeObject(subjectSubscriptions);
        } catch (IOException e) {
            System.out.println("Error saving subjects data: " + e.getMessage());
        }
    }

}
