package dev.ksan;

import com.gargoylesoftware.htmlunit.BrowserVersion;
import com.gargoylesoftware.htmlunit.WebClient;
import com.gargoylesoftware.htmlunit.html.DomElement;
import com.gargoylesoftware.htmlunit.html.HtmlAnchor;
import com.gargoylesoftware.htmlunit.html.HtmlElement;
import com.gargoylesoftware.htmlunit.html.HtmlPage;

import java.util.ArrayList;
import java.util.List;

public class ETFScraper implements Runnable {
    private List<SubjectEntry> entries = new ArrayList<>();

    private volatile boolean running = true;

    public ETFScraper() {
    }
    private static String getTextOrEmpty(HtmlElement parent,  String xPath) {
        HtmlElement element = parent.getFirstByXPath(xPath);
        return element == null ? "" : element.asNormalizedText();
    }
    List<SubjectEntry> getAllEntries() {
        return entries;
    }

    @Override
    public void run() {
        while(running) {
            try (final WebClient webClient = new WebClient(BrowserVersion.FIREFOX)) {

                webClient.getOptions().setJavaScriptEnabled(true);
                webClient.getOptions().setCssEnabled(false);
                webClient.getOptions().setThrowExceptionOnScriptError(false);

                HtmlPage mainPage = webClient.getPage("https://efee.etf.unibl.org/oglasi/");
                webClient.waitForBackgroundJavaScript(1000);

                List<DomElement> rawToggles = mainPage.getByXPath("//a[@href='#']");
                List<HtmlAnchor> toggles = new ArrayList<>();
                for (DomElement el : rawToggles) {
                    if (el instanceof HtmlAnchor) {
                        toggles.add((HtmlAnchor) el);
                    }
                }
                int ul_idSelection = 1;
                for (HtmlAnchor anchor : toggles) {
                    String groupName = anchor.asNormalizedText().split("\n")[0].trim();
                    System.out.println("Group name: " + groupName);
                    HtmlPage updatedPage = anchor.click();
                    webClient.waitForBackgroundJavaScript(1000);

                    String ul_id = "ul_id_" + Integer.toString(ul_idSelection);

                    DomElement rawElement = updatedPage.getElementById(ul_id);
                    HtmlElement listElement = rawElement instanceof HtmlElement ? (HtmlElement) rawElement : null;

                    if (listElement == null) {
                        System.out.println("An element with id " + ul_id + " was not found");
                        ul_idSelection++;
                        continue;
                    }

                    List<HtmlElement> items = listElement.getElementsByTagName("li");
                    for (HtmlElement item : items) {
                        String title = getTextOrEmpty(item, ".//h1");
                        String date = getTextOrEmpty(item, ".//h2[1]");
                        String info = getTextOrEmpty(item, ".//h2[2]");
                        List<String> paragraphs = new ArrayList<>();
                        List<HtmlElement> pTags = item.getByXPath(".//p");
                        for (HtmlElement pTag : pTags) {
                            paragraphs.add(pTag.asNormalizedText());
                        }
                        SubjectEntry entry = new SubjectEntry(title, date, info, paragraphs);

                        entries.add(entry);


                    }

                    ul_idSelection++;
                }

                Thread.sleep(20000);

            } catch (Exception e) {
                e.printStackTrace();
                System.out.println("ERROR: " + e.getMessage());
            }
        }
        System.out.println("WebScraper thread stopped");
    }
    public void stop(){
        running = false;
    }

}