package dev.ksan;

import com.gargoylesoftware.htmlunit.html.HtmlEmailInput;
import org.simplejavamail.api.email.Email;
import org.simplejavamail.api.mailer.Mailer;
import org.simplejavamail.api.mailer.config.TransportStrategy;
import org.simplejavamail.email.EmailBuilder;
import org.simplejavamail.mailer.MailerBuilder;
import java.io.*;
import java.util.*;

public class User implements Serializable {
    private static Set<String> usedIds =  new HashSet<>();

    private String id;
    private String email;
    private String password;
    private NotificationMethod notificationMethod;
    private Set<Subject> subjectSet = new HashSet<>();

    public User(String email, String password) {
        this.id = generateId();
        this.email = email;
        this.password = password;
        this.notificationMethod = NotificationMethod.EMAIL;
    }

    public void setNotificationMethod(NotificationMethod notificationMethod) {
        this.notificationMethod = notificationMethod;
    }
    public void serializeToFile(String filename) throws IOException {
        try (ObjectOutputStream oos = new ObjectOutputStream(new FileOutputStream(filename))) {
            oos.writeObject(this);
        }
    }

    public static User deserializeFromFile(String filename) throws IOException, ClassNotFoundException {
        try (ObjectInputStream ois = new ObjectInputStream(new FileInputStream(filename))) {
            return (User) ois.readObject();
        }
    }
    public static void saveUsedIds(String filename) throws IOException {
        try (ObjectOutputStream oos = new ObjectOutputStream(new FileOutputStream(filename))) {
            oos.writeObject(usedIds);
        }
    }

    @SuppressWarnings("unchecked")
    public static void loadUsedIds(String filename) throws IOException, ClassNotFoundException {
        try (ObjectInputStream ois = new ObjectInputStream(new FileInputStream(filename))) {
            usedIds = (Set<String>) ois.readObject();
        }
    }


    public void sendNotification(SubjectEntry entry){

        if(notificationMethod == NotificationMethod.EMAIL){
            sendEmail(entry);
        } else if (notificationMethod == NotificationMethod.PUSH_NOTIFICATION) {
            pushNotification(entry);
        }
    }
    private void pushNotification(SubjectEntry entry){
        //TODO
    }
    private void sendEmail(SubjectEntry entry) {
        MailService mail = new MailService(".env");
        mail.sendEmail(this.email,entry.getTitle(),entry.getParagraphs().toString());

    }

    public Set<Subject> getSubjectSet() {
        return subjectSet;
    }

    public void addSubject(Subject subject) {
        subjectSet.add(subject);
    }
    public void addSubjects(Set<Subject> subjects) {
        this.subjectSet.addAll(subjects);
    }
    public boolean addSubject(String subject) {
        Set<Subject> subjects = new HashSet<>();
        subjects = Subject.generateSubjects();

        System.out.println(subject);
        for(Subject s : subjects){
            if(s.equals(new Subject(subject))){
                this.subjectSet.add(s);
                return true;
                //break;
            }
        }
        return false;
    }
    public String getId() {
        return id;
    }
    public String getEmail() {
        return email;
    }
    public void setEmail(String email) {
        this.email = email;
    }
    public void setPassword(String password) {
        this.password = password;
    }
    private String generateId() {
        String id;
        do{
            id = UUID.randomUUID().toString();
        }while(usedIds.contains(id));
        usedIds.add(id);
        return id;
    }

}
